<?php

namespace Drupal\views_combine\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ViewExecutable;
use Drupal\views\Views;

/**
 * A handler to combine (unionize) views.
 *
 * @ingroup views_field_handlers
 *
 * @ViewsField("views_combine")
 */
class Combine extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);
    $this->options['exclude'] = 1;
  }

  /**
   * {@inheritdoc}
   */
  public function adminSummary() {
    return $this->options['view_id'];
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['view_id'] = ['default' => ''];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    $options = Views::getViewsAsOptions(FALSE, 'enabled', NULL, TRUE, TRUE);
    $form['view_id'] = [
      '#type' => 'select',
      '#title' => $this->t('Combine view'),
      '#description' => $this->t('The view to combine into this view.'),
      '#options' => $options,
      '#default_value' => $this->options['view_id'],
      '#required' => TRUE,
    ];
  }

  /**
   * {@inheritdoc}
   *
   * @see views_combine_views_pre_execute()
   */
  public function query() {
    // Do nothing. Sit back, relax, have a mojito.
  }

}
